smtping(1M)

smtping - send FDDI SMT Echo Request frames to FDDI stations

As shipped in IRIX 6.5.22. Unchanged since IRIX 6.5.

NAME
     smtping - send FDDI SMT Echo Request frames to FDDI stations

SYNOPSIS
     /usr/etc/smtping [-dfnqv] [-c count] [-s size] [-l preload]
          [-i interval] [-I interface] [-p pattern] host

DESCRIPTION
     smtping is a tool for FDDI ring testing, measurement and management.  It
     sends the FDDI Station Management (SMT) Echo request frames to elicit an
     Echo response frame from other FDDI stations or concentrators. Echo
     request frames (``pings'') have a MAC header, a SMT header, a transaction
     ID and an INFO field.  The INFO field has an 8-byte timestamp, and then
     an arbitrary number of ``pad'' bytes used to fill out the packet.  The
     smtping tests for SMT connectivity; the related utility, ping(1M), tests
     for the higher-level IP/ICMP connectivity.

     The host can be a MAC address of a host or the symbolic name of its MAC
     address which can be found in /etc/ethers or the NIS ethers.byname map.
     The options are:

     -c count
          Stop after sending (and receiving) count Echo frames.

     -d   Set the SO_DEBUG option on the socket being used.

     -f   Flood ping.  Outputs frames as fast as they come back or one hundred
          times per second, whichever is more.  For every Echo request frame
          sent, a period '.'  is printed, while for every Echo response
          received a backspace is printed.  This provides a rapid display of
          how many packets are being dropped.  Flooding can be extremely
          stressful on a network and should be used with caution.

     -i interval
          Wait interval seconds between sending each frame. The default is to
          wait for one second between each packet.  This option is
          incompatible with the -f option.

     -l preload
          Send preload frames as fast as possible before falling into the
          normal mode of behavior.

     -n   Numeric output only.  Does not try to translate the MAC address into
          its symbolic name in the ethers database.

     -p pattern
          Specify up to 16 ``pad'' bytes to fill out the frames sent.  This
          option is useful for diagnosing data-dependent problems in a
          network.  For example, ``-p ff'' will cause the sent frames to be
          filled with all 1s.

     -I interface
          Use interface to send each ECHO frame and receive responses. The
          interface is a string of the form ``name unit'', for example,
          ``ipg0''.  The default is set to the station's primary interface.

     -q   Quiet output.  Nothing is displayed except the summary line on
          termination.

     -s size
          Send frames containing size bytes of data.  The default is 12, which
          translates into 64-byte SMT frame.  The maximum allowed value is
          65468 bytes(even though smtping accepts up to 65468 bytes of packet
          size, any size larger than 4500 will result in failure because the
          maximum FDDI packet size is 4500).

     -v   Verbose output.  SMT frames other than Echo responses that are
          received are listed.

     smtping should be used primarily for manual fault isolation.  Because of
     the load it can impose on the network, it is unwise to use smtping during
     normal operations or from automated scripts.

     smtping continually sends one frame per second and prints one line of
     output for every Echo response returned.  If the -c count option is
     given, only that number of requests is sent.  No output is produced if
     the station does not respond.  Roundtrip times and frame loss statistics
     are computed.  If duplicate frames are received, they are not included in
     the frame loss calculation, although the round trip time of these frames
     is used in calculating the minimum/average/maximum round-trip time
     numbers.  When the specified number of frames have been sent (and
     received) or if the program is terminated with an interrupt (SIGINT), a
     brief summary is displayed.  When not using the -f (flood) option, the
     first interrupt, usually generated by control-C or DEL, causes smtping to
     wait for its outstanding requests to return.  It will wait no longer than
     the longest round trip time encountered by previous, successful pings.
     The second interrupt stops smtping immediately.

DUPLICATE AND DAMAGED PACKETS
     smtping will report duplicate and damaged packets.  Duplicate packets are
     expected if the target address is a multicast or broadcast address;
     otherwise duplicates are not expected.

     Damaged packets are obviously serious cause for alarm and often indicate
     broken hardware somewhere in the smtping packet's path (in the network or
     in the hosts).

TRYING DIFFERENT DATA PATTERNS
     The link-level layer should never treat packets differently depending on
     the data contained in the data portion.  Unfortunately, data-dependent
     problems have been known to sneak into networks and remain undetected for
     long periods of time.  In many cases the particular pattern that will
     have problems is something that doesn't have sufficient ``transitions'',
     such as all 1s or all 0s, or a pattern right at the edge, such as almost
     all 0s.  It isn't necessarily enough to specify a data pattern of all 0s
     (for example) on the command line because the pattern that is of interest
     is at the data link level, and the relationship between what you type and
     what the controllers transmit can be complicated.

     If you have a data-dependent problem you will probably have to do a lot
     of testing to find it.  If you are lucky, you may manage to find a file
     that either can't be sent across your network or takes much longer to
     transfer than other similar length files.  You can then examine this file
     for repeated patterns that you can test using the -p option of smtping.

FILES
     /etc/ethers    MAC address database

SEE ALSO
     smtstat(1), smtconfig(1M), ethers(4)